@@ -12,8 +12,8 @@ from . import test_metadata
 modules = [test_array, test_raggedarray, test_datadir, test_basedatadir,
            test_utils, test_numtype, test_datadir, test_metadata]
 
-def test(verbosity=1):
+def test(verbosity=1, buffer=True):
     suite = TestSuite()
     for module in modules:
         suite.addTests(TestLoader().loadTestsFromModule(module))
-    return TextTestRunner(verbosity=verbosity).run(suite)
\ No newline at end of file
+    return TextTestRunner(verbosity=verbosity, buffer=buffer).run(suite)
\ No newline at end of file
