@@ -5,11 +5,13 @@ import shutil
 
 import numpy as np
 
+import darr
 from darr.array import asarray, create_array, create_datadir, Array, \
     numtypesdescr, truncate_array, delete_array, AppendDataError, \
     numtypedescriptiontxt
 from darr.utils import tempdir, tempdirfile
 
+
 # TODO clean up overwrite parameters, not necessary anymore
 
 class DarrTestCase(unittest.TestCase):
@@ -284,6 +286,9 @@ class TestArray(DarrTestCase):
     def test_instantiatefromexistingpath(self):
         Array(path=self.temparpath)
 
+    def test_openfromexistingpath(self):
+        darr.open(path=self.temparpath)
+
     def test_instantiatefromnonexistingpath(self):
        with self.assertRaises(OSError):
             Array(path=self.tempnonarpath)
